Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorBastien Montagne <montagne29@wanadoo.fr>2012-09-05 22:35:22 +0400
committerBastien Montagne <montagne29@wanadoo.fr>2012-09-05 22:35:22 +0400
commitb9e544e82312526af951c4ce34aa99cb680c5a49 (patch)
tree0d44804964734c19dc3e3f9b32b4e8db8fc3b69a
parentd4902771947372f10fb095629021a3e247887d92 (diff)
Adding brazilian portuguese language, as requested by portuguese team.
-rw-r--r--source/blender/blenfont/intern/blf_lang.c3
-rw-r--r--source/blender/makesrna/intern/rna_userdef.c3
2 files changed, 4 insertions, 2 deletions
diff --git a/source/blender/blenfont/intern/blf_lang.c b/source/blender/blenfont/intern/blf_lang.c
index b37180d499c..55a65f07759 100644
--- a/source/blender/blenfont/intern/blf_lang.c
+++ b/source/blender/blenfont/intern/blf_lang.c
@@ -82,7 +82,7 @@ static const char *locales[] = {
"spanish", "es",
"catalan", "ca_AD",
"czech", "cs_CZ",
- "portuguese", "pt",
+ "portuguese", "pt_PT",
#if defined(_WIN32) && !defined(FREE_WINDOWS)
"Chinese (Simplified)_China.1252", "zh_CN",
"Chinese (Traditional)_China.1252", "zh_TW",
@@ -107,6 +107,7 @@ static const char *locales[] = {
"kyrgyz", "ky_KG",
"turkish", "tr_TR",
"hungarian", "hu_HU",
+ "brazilian portuguese", "pt_BR",
};
void BLF_lang_init(void)
diff --git a/source/blender/makesrna/intern/rna_userdef.c b/source/blender/makesrna/intern/rna_userdef.c
index 7cebbe5a895..f753ff680fd 100644
--- a/source/blender/makesrna/intern/rna_userdef.c
+++ b/source/blender/makesrna/intern/rna_userdef.c
@@ -2982,11 +2982,12 @@ static void rna_def_userdef_system(BlenderRNA *brna)
/* locale according to http://www.roseindia.net/tutorials/I18N/locales-list.shtml */
/* if you edit here, please also edit the source/blender/blenfont/intern/blf_lang.c 's locales */
/* Note: As this list is in alphabetical order, and not defined order,
* here is the highest define currently in use: 31 (Hungarian). */
static EnumPropertyItem language_items[] = {
{ 0, "", 0, N_("Nearly done"), ""},
{ 0, "DEFAULT", 0, "Default (Default)", ""},
{21, "ARABIC", 0, "Arabic (ﺔﻴﺑﺮﻌﻟﺍ)", "ar_EG"},
+ {32, "BRAZILIANPORTUGUESE", 0, "Brazilian Portuguese (Português do Brasil)", "pt_BR"},
{ 1, "ENGLISH", 0, "English (English)", "en_US"},
{ 8, "FRENCH", 0, "French (Français)", "fr_FR"},
{ 4, "ITALIAN", 0, "Italian (Italiano)", "it_IT"},
@@ -2982,11 +2982,12 @@ static void rna_def_userdef_system(BlenderRNA *brna)
/* if you edit here, please also edit the source/blender/blenfont/intern/blf_lang.c 's locales */
/* Note: As this list is in alphabetical order, and not defined order,
- * here is the highest define currently in use: 31 (Hungarian). */
+ * here is the highest define currently in use: 32 (Brazilian Portuguese). */
static EnumPropertyItem language_items[] = {
{ 0, "", 0, N_("Nearly done"), ""},